/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
import React from "react";
import { Link } from "react-router-dom";
import {useThemeConfig} from "@docusaurus/theme-common";
import FooterLinks from "@theme/Footer/Links";
import FooterLogo from "@theme/Footer/Logo";
import FooterCopyright from "@theme/Footer/Copyright";
import FooterLayout from "@theme/Footer/Layout";
import { FaYoutube, FaLinkedin, FaGitlab, FaTwitter } from "react-icons/fa";
import Froggitblanc from "/static/img/theme/logo_froggit_blanc.png";
import DontTrackMe from "/static/img/theme/do-not-track-me.svg";
import useBaseUrl from "@docusaurus/useBaseUrl";
import { WebsiteCarbonBadge } from "react-websitecarbon-badge";


function Footer() {
  const {footer} = useThemeConfig();

  if (!footer) {
    return null;
  }

  const {copyright, icons, links, logo, style, FooterIcons} = footer;
  return (
    <>
      <div className="footer">
        <img src="https://tracker.metricool.com/c3po.jpg?hash=6978378a1fd2834207b6e52e0030292d"/>

        <div className="footer-container">

          <a href="https://lab.frogg.it/froggit" target="_blank" rel="noreferrer">
            <img className="footer-icons" src={Froggitblanc} alt="Logo Froggit blanc" />
          </a>

          <a href="https://gitlab.com/froggit" target="_blank" rel="noreferrer">
            <FaGitlab className="footer-icons" />
          </a>

          <a href="https://www.youtube.com/@MentorDevOps?sub_confirmation=1" target="_blank" rel="noreferrer">
            <FaYoutube className="footer-icons" />
          </a>

          <a href="https://www.linkedin.com/company/froggit" target="_blank" rel="noreferrer">
            <FaLinkedin className="footer-icons" />
          </a>
          
          <a href="https://twitter.com/froggit_fr" target="_blank" rel="noreferrer">
            <FaTwitter className="footer-icons" />
          </a>

        </div>

        <div>
          <FooterLayout
            icons={icons && <FooterIcons icons={icons} />}
            style={style}
            links={links && links.length > 0 && <FooterLinks links={links} />}
            logo={logo && <FooterLogo logo={logo} />}
            copyright={copyright && <FooterCopyright copyright={copyright} />}
          />
        </div>
        <div className="footerBadges">
          <Link to={useBaseUrl("/confidentialite#ne-me-trackez-pas")} className="notrack_container">
            <div>
              <DontTrackMe className="no_track" />
            </div>
          </Link> 
          <WebsiteCarbonBadge dark="false" url="https://froggit.fr/" lang="fr"/>
        </div>      
      </div>
    </>
  );
}

export default React.memo(Footer);
